{ config, pkgs, ... }:
{
    imports = [
        ./gitea.nix
    ];

    boot.loader.grub.enable = true;
    boot.loader.grub.version = 2;
    boot.loader.grub.device = "/dev/vda";

    networking.hostName = "Emitter";

    networking.useDHCP = false;
    networking.interfaces.ens3.useDHCP = true;

    i18n.defaultLocale = "de_DE.UTF-8";
    console.keyMap = "de";

    services.openssh.ports = [ 8248 ];
    networking.firewall.allowedTCPPorts = [ 8248 ];

    nix.settings.trusted-users = [ "fruchti" ];
    security.sudo.wheelNeedsPassword = false;

    security.acme = {
        defaults = {
            email = config.email.adminEmail;
        };
        acceptTerms = true;
    };

    system.autoUpgrade = {
        enable = true;
        allowReboot = true;
        sendEmail = true;
        gitPull = true;
        gitUser = "fruchti";
    };

    # This value determines the NixOS release from which the default
    # settings for stateful data, like file locations and database versions
    # on your system were taken. It’s perfectly fine and recommended to leave
    # this value at the release version of the first install of this system.
    # Before changing this value read the documentation for this option
    # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
    system.stateVersion = "21.11"; # Did you read the comment?
}

